@@ -31,6 +31,16 @@ class JSONField(models.TextField):
     }
     description = "JSON object"
     
+    def __init__(self, *args, **kwargs):
+        if not kwargs.get('null', False):
+            kwargs['default'] = kwargs.get('default', {})
+        super(JSONField, self).__init__(*args, **kwargs)
+        if 'default' in kwargs:
+            if callable(self.default):
+                self.validate(self.default(), None)
+            else:
+                self.validate(self.default, None)
+        
     def formfield(self, **kwargs):
         return super(JSONField, self).formfield(form_class=JSONFormField, **kwargs)
     
@@ -38,9 +48,9 @@ class JSONField(models.TextField):
         if not self.null and value is None:
             raise ValidationError(self.error_messages['null'])
         try:
-            self.get_db_prep_value(value)
+            self.get_prep_value(value)
         except:
-            raise ValidationError(self.error_messages['invalid'])
+            raise ValidationError(self.error_messages['invalid'] % value)
 
     def get_default(self):
         if self.has_default():
@@ -67,6 +77,9 @@ class JSONField(models.TextField):
         return value
 
     def get_db_prep_value(self, value, connection=None, prepared=None):
+        return self.get_prep_value(value)
+    
+    def get_prep_value(self, value):
         if value is None:
             if not self.null and self.blank:
                 return ""
@@ -75,9 +88,9 @@ class JSONField(models.TextField):
     
     def get_prep_lookup(self, lookup_type, value):
         if lookup_type in ["exact", "iexact"]:
-            return self.to_python(self.get_db_prep_value(value))
+            return self.to_python(self.get_prep_value(value))
         if lookup_type == "in":
-            return [self.to_python(self.get_db_prep_value(v)) for v in value]
+            return [self.to_python(self.get_prep_value(v)) for v in value]
         if lookup_type == "isnull":
             return value
         if lookup_type in ["contains", "icontains"]:
@@ -86,10 +99,10 @@ class JSONField(models.TextField):
                     lookup_type, type(value).__name__
                 ))
                 # Need a way co combine the values with '%', but don't escape that.
-                return self.get_db_prep_value(value)[1:-1].replace(', ', r'%')
+                return self.get_prep_value(value)[1:-1].replace(', ', r'%')
             if isinstance(value, dict):
-                return self.get_db_prep_value(value)[1:-1]
-            return self.to_python(self.get_db_prep_value(value))
+                return self.get_prep_value(value)[1:-1]
+            return self.to_python(self.get_prep_value(value))
         raise TypeError('Lookup type %r not supported' % lookup_type)
 
     def value_to_string(self, obj):
