@@ -38,15 +38,6 @@ class JSONFieldTest(DjangoTestCase):
         self.assertEquals(None, field.get_db_prep_save(None, connection=None))
         self.assertEquals('{"spam": "eggs"}', field.get_db_prep_save({"spam": "eggs"}, connection=None))
 
-    @unittest.expectedFailure
-    def test_value_to_string(self):
-        field = JSONField(u"test")
-        field.set_attributes_from_name("json")
-        obj = JSONFieldTestModel(json='''{
-            "spam": "eggs"
-        }''')
-        self.assertEquals(u'{"spam": "eggs"}', field.value_to_string(obj))
-
     def test_formfield(self):
         from jsonfield.forms import JSONFormField
         from jsonfield.widgets import JSONWidget
@@ -93,4 +84,3 @@ class JSONFieldTest(DjangoTestCase):
         obj = BlankJSONFieldTestModel.objects.get()
         self.assertEquals(None, obj.null_json)
         self.assertEquals("", obj.blank_json)
-        
\ No newline at end of file
